==> pcep-tunnel-api-0.16.12-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/topology/tunnel/pcep/programming/rev181109/PcepUpdateTunnelOutputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.tunnel.pcep.programming.rev181109;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.programming.rev150720.SubmitInstructionOutput;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.programming.rev150720.submit.instruction.output.Result;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.programming.rev131102.TopologyInstructionOutput;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.tunnel.programming.rev130930.BaseTunnelOutput;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link PcepUpdateTunnelOutputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     PcepUpdateTunnelOutputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new PcepUpdateTunnelOutputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of PcepUpdateTunnelOutputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see PcepUpdateTunnelOutputBuilder
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class PcepUpdateTunnelOutputBuilder implements Builder<PcepUpdateTunnelOutput> {

    private Result _result;


    Map<Class<? extends Augmentation<PcepUpdateTunnelOutput>>, Augmentation<PcepUpdateTunnelOutput>> augmentation = Collections.emptyMap();

    public PcepUpdateTunnelOutputBuilder() {
    }
    
    
    
    public PcepUpdateTunnelOutputBuilder(BaseTunnelOutput arg) {
        this._result = arg.getResult();
    }
    public PcepUpdateTunnelOutputBuilder(TopologyInstructionOutput arg) {
        this._result = arg.getResult();
    }
    public PcepUpdateTunnelOutputBuilder(SubmitInstructionOutput arg) {
        this._result = arg.getResult();
    }

    public PcepUpdateTunnelOutputBuilder(PcepUpdateTunnelOutput base) {
        Map<Class<? extends Augmentation<PcepUpdateTunnelOutput>>, Augmentation<PcepUpdateTunnelOutput>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._result = base.getResult();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>BaseTunnelOutput</li>
     * <li>TopologyInstructionOutput</li>
     * <li>SubmitInstructionOutput</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof BaseTunnelOutput) {
            isValidArg = true;
        }
        if (arg instanceof TopologyInstructionOutput) {
            isValidArg = true;
        }
        if (arg instanceof SubmitInstructionOutput) {
            this._result = ((SubmitInstructionOutput)arg).getResult();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[BaseTunnelOutput, TopologyInstructionOutput, SubmitInstructionOutput]");
    }

    public Result getResult() {
        return _result;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<PcepUpdateTunnelOutput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public PcepUpdateTunnelOutputBuilder setResult(final Result value) {
        this._result = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public PcepUpdateTunnelOutputBuilder addAugmentation(Augmentation<PcepUpdateTunnelOutput> augmentation) {
        Class<? extends Augmentation<PcepUpdateTunnelOutput>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public PcepUpdateTunnelOutputBuilder removeAugmentation(Class<? extends Augmentation<PcepUpdateTunnelOutput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public PcepUpdateTunnelOutput build() {
        return new PcepUpdateTunnelOutputImpl(this);
    }

    private static final class PcepUpdateTunnelOutputImpl
        extends AbstractAugmentable<PcepUpdateTunnelOutput>
        implements PcepUpdateTunnelOutput {
    
        private final Result _result;
    
        PcepUpdateTunnelOutputImpl(PcepUpdateTunnelOutputBuilder base) {
            super(base.augmentation);
            this._result = base.getResult();
        }
    
        @Override
        public Result getResult() {
            return _result;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = PcepUpdateTunnelOutput.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return PcepUpdateTunnelOutput.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return PcepUpdateTunnelOutput.bindingToString(this);
        }
    }
}

==> pcep-tunnel-api-0.20.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/topology/tunnel/pcep/programming/rev181109/PcepUpdateTunnelOutputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.tunnel.pcep.programming.rev181109;
import java.lang.Class;
import java.lang.IllegalArgumentException;
import java.lang.NullPointerException;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.programming.rev150720.SubmitInstructionOutput;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.programming.rev150720.submit.instruction.output.Result;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.programming.rev131102.TopologyInstructionOutput;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.topology.tunnel.programming.rev130930.BaseTunnelOutput;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link PcepUpdateTunnelOutput} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     PcepUpdateTunnelOutput createPcepUpdateTunnelOutput(int fooXyzzy, int barBaz) {
 *         return new PcepUpdateTunnelOutputBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of PcepUpdateTunnelOutput, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization opportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see PcepUpdateTunnelOutput
 *
 */
@Generated("mdsal-binding-generator")
public class PcepUpdateTunnelOutputBuilder {

    private Result _result;


    Map<Class<? extends Augmentation<PcepUpdateTunnelOutput>>, Augmentation<PcepUpdateTunnelOutput>> augmentation = Map.of();

    /**
     * Construct an empty builder.
     */
    public PcepUpdateTunnelOutputBuilder() {
        // No-op
    }

    
    
    /**
     * Construct a new builder initialized from specified {@link BaseTunnelOutput}.
     *
     * @param arg BaseTunnelOutput from which the builder should be initialized
     */
    public PcepUpdateTunnelOutputBuilder(BaseTunnelOutput arg) {
        this._result = arg.getResult();
    }
    
    /**
     * Construct a new builder initialized from specified {@link TopologyInstructionOutput}.
     *
     * @param arg TopologyInstructionOutput from which the builder should be initialized
     */
    public PcepUpdateTunnelOutputBuilder(TopologyInstructionOutput arg) {
        this._result = arg.getResult();
    }
    
    /**
     * Construct a new builder initialized from specified {@link SubmitInstructionOutput}.
     *
     * @param arg SubmitInstructionOutput from which the builder should be initialized
     */
    public PcepUpdateTunnelOutputBuilder(SubmitInstructionOutput arg) {
        this._result = arg.getResult();
    }
    

    /**
     * Construct a builder initialized with state from specified {@link PcepUpdateTunnelOutput}.
     *
     * @param base PcepUpdateTunnelOutput from which the builder should be initialized
     */
    public PcepUpdateTunnelOutputBuilder(PcepUpdateTunnelOutput base) {
        final var aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._result = base.getResult();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     *   <li>{@link BaseTunnelOutput}</li>
     *   <li>{@link TopologyInstructionOutput}</li>
     *   <li>{@link SubmitInstructionOutput}</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof BaseTunnelOutput castArg) {
            isValidArg = true;
        }
        if (arg instanceof TopologyInstructionOutput castArg) {
            isValidArg = true;
        }
        if (arg instanceof SubmitInstructionOutput castArg) {
            this._result = castArg.getResult();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[BaseTunnelOutput, TopologyInstructionOutput, SubmitInstructionOutput]");
    }


    /**
     * Return current value associated with the property corresponding to {@link PcepUpdateTunnelOutput#getResult()}.
     *
     * @return current value
     */
    public Result getResult() {
        return _result;
    }

    /**
     * Return the specified augmentation, if it is present in this builder.
     *
     * @param <E$$> augmentation type
     * @param augmentationType augmentation type class
     * @return Augmentation object from this builder, or {@code null} if not present
     * @throws NullPointerException if {@code augmentType} is {@code null}
     */
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<PcepUpdateTunnelOutput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    /**
     * Set the property corresponding to {@link PcepUpdateTunnelOutput#getResult()} to the specified
     * value.
     *
     * @param value desired value
     * @return this builder
     */
    public PcepUpdateTunnelOutputBuilder setResult(final Result value) {
        this._result = value;
        return this;
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public PcepUpdateTunnelOutputBuilder addAugmentation(Augmentation<PcepUpdateTunnelOutput> augmentation) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentation.implementedInterface(), augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public PcepUpdateTunnelOutputBuilder removeAugmentation(Class<? extends Augmentation<PcepUpdateTunnelOutput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    /**
     * A new {@link PcepUpdateTunnelOutput} instance.
     *
     * @return A new {@link PcepUpdateTunnelOutput} instance.
     */
    public @NonNull PcepUpdateTunnelOutput build() {
        return new PcepUpdateTunnelOutputImpl(this);
    }

    private static final class PcepUpdateTunnelOutputImpl
        extends AbstractAugmentable<PcepUpdateTunnelOutput>
        implements PcepUpdateTunnelOutput {
    
        private final Result _result;
    
        PcepUpdateTunnelOutputImpl(PcepUpdateTunnelOutputBuilder base) {
            super(base.augmentation);
            this._result = base.getResult();
        }
    
        @Override
        public Result getResult() {
            return _result;
        }
    
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = PcepUpdateTunnelOutput.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return PcepUpdateTunnelOutput.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return PcepUpdateTunnelOutput.bindingToString(this);
        }
    }
}
